# Changelog
All notable changes to this project will be documented in this file.

## [0.4.0] - 02.08.2022
### Changed
* Refactored PhageAI API connectors;


## [0.3.1] - 24.02.2022
### Changed
* Bugfix for URL addresses;


## [0.3.0] - 22.10.2021
### Added
* Added method for fetching bacteriophage meta-data;
* Added method for calculating alignment-free phage similarity (top-10);
### Changed
* `README.md` updated;


## [0.2.0] - 03.08.2021
### Added
* Added user requests limit support;
* Added chronic lifecycle support;
### Changed
* `README.md` updated;


## [0.1.1] - 03.12.2020
### Changed
* `README.md` updated;


## [0.1.0] - 12.11.2020
### Added
* Added `LifeCycleClassifier` support to istinguish between the two major types of phages life cycles: lytic and lysogenic;
